@@ -334,6 +334,7 @@ class DulwichBackend(BaseGitBackend):  # pylint:disable=abstract-method
             raise SCMError(f"Failed to set '{name}'")
 
     def get_ref(self, name, follow: bool = True) -> Optional[str]:
+        from dulwich.objects import Tag
         from dulwich.refs import parse_symref_value
 
         name_b = os.fsencode(name)
@@ -350,6 +351,8 @@ class DulwichBackend(BaseGitBackend):  # pylint:disable=abstract-method
             except ValueError:
                 pass
         if ref:
+            if ref in self.repo and isinstance(self.repo[ref], Tag):
+                ref = self.repo.get_peeled(name_b)
             return os.fsdecode(ref)
         return None
 
@@ -590,7 +593,7 @@ class DulwichBackend(BaseGitBackend):  # pylint:disable=abstract-method
         except ValueError as exc:
             raise SCMError("Failed to drop stash entry") from exc
 
-    def describe(
+    def _describe(
         self,
         rev: str,
         base: Optional[str] = None,
